@@ -45,6 +45,10 @@ class DaylightFactorEntryPoint(DAG):
         """Translate the input model to a radiance folder."""
         return [
             {'from': CreateRadianceFolder()._outputs.model_folder, 'to': 'model'},
+            {
+                'from': CreateRadianceFolder()._outputs.sensor_grids_file,
+                'to': 'results/grids_info.json'
+            },
             {
                 'from': CreateRadianceFolder()._outputs.sensor_grids,
                 'description': 'Sensor grids information.'
